#include <R.h>
#include <Rinternals.h>

extern SEXP DASarrayFnCpp(SEXP nXbasisw, SEXP nWbasisw, SEXP nUbasisj, SEXP nAbasisj, 
                          SEXP BVECW,    SEXP UCOEFJ,   SEXP BATENS);

